self.__precacheManifest = (self.__precacheManifest || []).concat([
  {
    "revision": "73f38cc649269252791eaaa4ef05a2a1",
    "url": "./index.html"
  },
  {
    "revision": "f675c301495b8b79dacd",
    "url": "./static/js/2.33d556d4.chunk.js"
  },
  {
    "revision": "fbabe484400fd249a0740ba2c0d294dd",
    "url": "./static/js/2.33d556d4.chunk.js.LICENSE.txt"
  },
  {
    "revision": "aa10ff5d7bf67c990a3e",
    "url": "./static/js/main.508efdfd.chunk.js"
  },
  {
    "revision": "5ab337871dec8eeaf644",
    "url": "./static/js/runtime-main.fd5c39a2.js"
  }
]);